package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.service.ISysResourceRoleService
import com.gxzc.zen.api.sys.service.ISysResourceService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.config.request.annotation.KVType
import com.gxzc.zen.common.config.request.annotation.KVTypeEnum
import com.gxzc.zen.common.config.request.annotation.ZenRequestTypes
import com.gxzc.zen.common.dto.RequestDto
import com.gxzc.zen.common.dto.ResponseDto
import io.swagger.annotations.ApiOperation
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 资源-角色 控制器
 * @author NorthLan
 * @date 2018/5/4
 * @url https://noahlan.com
 */
@RestController
@RequestMapping
class ResourceRoleController : BaseController() {
    @Autowired
    private lateinit var resourceService: ISysResourceService

    @Autowired
    private lateinit var resourceRoleService: ISysResourceRoleService

    @ApiOperation("获取某角色拥有的资源列表")
    @GetMapping("/role/{rid}/resource")
    fun getResourceByRoleId(@PathVariable rid: Long): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = resourceService.getResourcesByRoleId(rid)
        })
    }

    @Suppress("UNCHECKED_CAST")
    @ApiOperation("保存(新增或更新用户资源映射表)")
    @PostMapping("/role/{rid}/resource")
    @ZenRequestTypes(KVType(key = "list", value = Long::class, type = KVTypeEnum.LIST), KVType(key = "menuId", value = Long::class))
    fun postResourceByRoleId(@PathVariable rid: Long, @RequestBody requestDto: RequestDto): ResponseEntity<*> {
        val menuId = requestDto["menuId"] as Long
        val list = requestDto["list"] as List<Long>
        resourceRoleService.saveResourceRoleByRoleId(rid, menuId, list)
        return ResponseEntity.ok(ResponseDto())
    }
}